<?php
/**
 * Example to use myMVC.
 * This program just demonstrate how to create
 * a login form, authenticate user, check data from
 * a form and read data from database.
 * 
 * Author: Luca Bertoncello <lucabert@lucabert.de>
 */

/**
 * Example for an action that receives data from user
 * and validate them.
 */
class ListAction extends myMVC_BaseAction
{
  public function __construct($request, $session)
  {
    parent::__construct($request, $session);
// Setting validation function
    $this->setCheckFunction('POST', 'validatePost');
  }

  /**
   * Returns the token used to identify the current Action
   * 
   * @return string                 The token
   */
  public static function getActionToken()
  {
    return 'list';
  }

  /**
   * Returns whether this action should appear in the menu (created by controller)
   * 
   * @return boolean                true if the action should appear in menu
   */
  public static function isMenuAction()
  {
// Yes, this action can be called from menu!
    return true;
  }

  /**
   * Returns the string to be displayed in the menu to identify the current action.
   * Only necessary if isMenuAction() returns true
   * 
   * @return string                 The menu item
   */
  public static function getActionMenuName()
  {
// This string will be displayed in menu.
// Please note, that all strings, here, use GetText!
    return _('List');
  }

  /**
   * Returns whether the current user is allowed to call the current Action
   * 
   * @return boolean                true if the user may call this Action, false otherwise
   */
  public static function hasUserRightForAction()
  {
// And yes: the user can call this action! :D
    return true;
  }

  /**
   * Validate the data from user, coming as POST (form submit).
   * 
   * @return boolean                true if data are valid, false otherwise
   */
  public function validatePost()
  {
    $this->session->useNamespace('list');
    if($this->request->getSubmitParameter('delEntry') != '')
    {
      $definitions = array(
          'list' => array('type' => myMVC_BaseAction::$VALIDATE_STRING, 'empty' => false, 'range' => $this->session->get('list')),
      );
    }
    if($this->request->getSubmitParameter('addEntry') != '')
    {
      $definitions = array(
          'entry' => array('type' => myMVC_BaseAction::$VALIDATE_STRING, 'empty' => false, 'minlen' => 3, 'maxlen' => 10),
      );
    }
    $names = array(
        'list' => _('List'),
        'entry' => _('New entry'),
    );
    $errorMsgs = array(
        'entry'     => array(myMVC_BaseAction::$ERROR_MINLEN  => sprintf(_("%s must be at least %s char long"),
                                               '{field}', '{checkValue}'),
                             myMVC_BaseAction::$ERROR_MAXLEN  => sprintf(_("%s must be no more that %s char long"),
                                               '{field}', '{checkValue}'),
                             myMVC_BaseAction::$ERROR_EMPTY   => sprintf(_("%s cannot be empty"),
                                               '{field}')),
        'list'      => array(myMVC_BaseAction::$ERROR_RANGE  => sprintf(_("%s is unknown"),
                                               '{field}')),
    );
    return parent::validateInput($definitions, $names, $errorMsgs);
  }

// This action always call ListView
  /**
   * Perform the Action
   * 
   * @return myMVC_HttpResponse     Response code for the next Action or View
   */
  public function perform()
  {
    $response = new myMVC_HttpResponse();
    $response->setNext('ListView');

    $this->session->useNamespace('list');
    if($this->isCalledFromMenu())
    {
      $this->session->emptyNamespace();
      $values = array('abcdef', '123456', 'GHILMN');
      $this->session->set('list', $values);
    }
    else
    {
      if($this->request->getSubmitParameter('addEntry') != '')
      {
        $values = $this->session->get('list');
        array_push($values, $this->request->getParameter('entry'));
        $this->session->set('list', $values);
      }
      if($this->request->getSubmitParameter('delEntry') != '')
      {
        $values = $this->session->get('list');
        $nValues = array();
        foreach($values as $v)
          if($v != $this->request->getParameter('list'))
            array_push($nValues, $v);
        $this->session->set('list', $nValues);
      }
    }
    return $response;
  }

  /**
   * Called if user data are not valid (check with validate)
   * 
   * @return myMVC_HttpResponse     Response code for the next Action or View
   */
  public function manageInvalidData()
  {
    $response = new myMVC_HttpResponse();
    $response->setNext('ListView');
    return $response;
  }
}
?>
