<?php
/**
 * Example to use myMVC.
 * This program just demonstrate how to create
 * a login form, authenticate user, check data from
 * a form and read data from database.
 * 
 * Author: Luca Bertoncello <lucabert@lucabert.de>
 */

/**
 * Login-Actionclass. It <b>must</b> be derived from
 * myMVC_BaseLoginAction.
 * You can see how to define a validate-Function (setCheckFunction)
 * and how to validate data (validatePost).
 * In the perform-function, if the user logged in, you <b>must</b>
 * call $this->setLoggedIn($user);
 * $user contains an instance of a myMVC_BaseLogin derived class.
 * After a successfully login, you can call setNextAction() to
 * redirect to the main action or, if the user called it (eg. from bookmark)
 * to the wanted action.
 */
class LoginAction extends myMVC_BaseLoginAction
{
  public function __construct($request, $session)
  {
    parent::__construct($request, $session);
    $this->setCheckFunction('POST', 'validatePost');
  }

  /**
   * Validate the data from user, coming as POST (form submit).
   * 
   * @return boolean                true if data are valid, false otherwise
   */
  public function validatePost()
  {
    $definitions = array();
    if($this->request->getSubmitParameter('loginButton') != '')
// Login and password must be at least 3 chars long and cannot be empty
      $definitions = array(
          'login' => array('type' => myMVC_BaseAction::$VALIDATE_STRING, 'minlen' => 3, 'empty' => false),
          'passwd' => array('type' => myMVC_BaseAction::$VALIDATE_STRING, 'minlen' => 3, 'empty' => false),
      );
    $names = array(
        'login' => 'Login',
        'passwd' => 'Passwort',
    );
    $errorMsgs = array(
        'login'     => array(myMVC_BaseAction::$ERROR_MINLEN  => sprintf(_("%s must be at least %s char long"),
                                               '{field}', '{checkValue}'),
                             myMVC_BaseAction::$ERROR_EMPTY   => sprintf(_("%s cannot be empty"),
                                               '{field}')),
        'passwd'    => array(myMVC_BaseAction::$ERROR_MINLEN  => sprintf(_("%s must be at least %s char long"),
                                               '{field}', '{checkValue}'),
                             myMVC_BaseAction::$ERROR_EMPTY   => sprintf(_("%s cannot be empty"),
                                               '{field}')),
    );
    return parent::validateInput($definitions, $names, $errorMsgs);
  }

  /**
   * Perform the Action
   * 
   * @return myMVC_HttpResponse     Response code for the next Action or View
   */
  public function perform()
  {
    $response = new myMVC_HttpResponse();
    if($this->request->getRequestMethod() == 'GET')
      $response->setNext('LoginView');
    else
    {
      if($this->request->getSubmitParameter('loginButton') != '')
      {
// The next four lines are not very wise...
// Normally, you should search the user in the database.
// But this is just an example.
        $user = new login();
        $user->setLogin($this->request->getParameter('login'));
        $user->setFirstname('Max');
        $user->setLastname('Mustermann');
        if($user->isPasswordCorrect($this->request->getParameter('passwd')))
        {
// OK, user logged in. Save this information in the session
          $this->setLoggedIn($user);
// Call wanted or default action
          $this->setNextAction($response);
        }
        else
        {
          $response->setNext('LoginView');
          $this->saveParameterForNextPage('nologin', true);
        }
      }
    }
    return $response;
  }

  /**
   * Called if user data are not valid (check with validate)
   * 
   * @return myMVC_HttpResponse     Response code for the next Action or View
   */
  public function manageInvalidData()
  {
    $response = new myMVC_HttpResponse();
    $response->setNext('LoginView');
    return $response;
  }
}
?>
