<?php
/**
 * Example to use myMVC.
 * This program just demonstrate how to create
 * a login form, authenticate user, check data from
 * a form and read data from database.
 * 
 * Author: Luca Bertoncello <lucabert@lucabert.de>
 */

/**
 * Example of a class, that should NOT be called.
 * A link to this Action is in the main page, but
 * the user has no rights to view this page.
 * Then, if the user tries to call this action, the
 * NoRightsAction will be called instead.
 */
class Test1Action extends myMVC_BaseAction
{
  /**
   * Returns the token used to identify the current Action
   * 
   * @return string                 The token
   */
  public static function getActionToken()
  {
    return 'test1';
  }

  /**
   * Returns whether the current user is allowed to call the current Action
   * 
   * @return boolean                true if the user may call this Action, false otherwise
   */
  public static function hasUserRightForAction()
  {
// No one can call this action...
// Normally, you should check here if the current logged
// user has the rights for this page.
// See the static function getLoggedUser() in myMVC_BasePage
// You can use such a code, to check, if the logged user has rights:
//    $user = self::getLoggedUser();
//    if($user !== NULL && $user->getLogin() == 'tester')
//      return true;
//    return false;
    return false;
  }

  /**
   * Perform the Action
   * 
   * @return myMVC_HttpResponse     Response code for the next Action or View
   */
  public function perform()
  {
    $response = new myMVC_HttpResponse();
    $response->setNext('Test1View');
    return $response;
  }
}
?>
