<?php
/**
 * Example to use myMVC.
 * This program just demonstrate how to create
 * a login form, authenticate user, check data from
 * a form and read data from database.
 * 
 * Author: Luca Bertoncello <lucabert@lucabert.de>
 */

/**
 * Very simple Action-class.
 * It just call a View.
 */
class TestAction extends myMVC_BaseAction
{
  /**
   * Returns the token used to identify the current Action
   * 
   * @return string                 The token
   */
  public static function getActionToken()
  {
    return 'test';
  }

  /**
   * Returns whether the current user is allowed to call the current Action
   * 
   * @return boolean                true if the user may call this Action, false otherwise
   */
  public static function hasUserRightForAction()
  {
    return true;
  }

  /**
   * Returns whether this action should appear in the menu (created by controller)
   * 
   * @return boolean                true if the action should appear in menu
   */
  public static function isMenuAction()
  {
    return true;
  }

  /**
   * Returns the string to be displayed in the menu to identify the current action.
   * Only necessary if isMenuAction() returns true
   * 
   * @return string                 The menu item
   */
  public static function getActionMenuName()
  {
    return 'Test';
  }

  /**
   * Perform the Action
   * 
   * @return myMVC_HttpResponse     Response code for the next Action or View
   */
  public function perform()
  {
    $response = new myMVC_HttpResponse();
    $response->setNext('TestView');
    return $response;
  }
}
?>
