<?php
/**
 * Example to use myMVC.
 * This program just demonstrate how to create
 * a login form, authenticate user, check data from
 * a form and read data from database.
 * 
 * Author: Luca Bertoncello <lucabert@lucabert.de>
 */

/**
 * My own autoload function...
 */
function __autoload($class)
{
  require_once('/path/to/your/application/incs/'.$class.'.php');
}

// Path to the Smarty-library
define('SMARTY_DIR', '/path/to/your/Smarty/libs/');
require_once(SMARTY_DIR.'Smarty.class.php');
// PLEASE NOTE: FIRST you have to include myMVC.php, THEN your etc.php!!!
require_once('mymvc/myMVC.php');
require_once('../etc/etc.php');

// Setting own exception handler (not mandatory!)
myMVC_ErrorHandler::setUserExceptionCatcher('myCatcher');

// New instance of the controller
$controller = new myMVC_Controller();
// We use the SmartyEngine. It takes as arguments the path to the templates und to the directory to compile them
$controller->setRenderEngine(new myMVC_SmartyEngine($_SERVER['DOCUMENT_ROOT'].'/../pages/templates',
                                                    $_SERVER['DOCUMENT_ROOT'].'/../pages/templates_c'));
// List of the valid actions (in the array), the default action (MainAction) and the action to be called
// if the user does not have the necessary rights (NoRightsAction)
$controller->setActions(array('MainAction', 'TestAction', 'Test1Action', 'TestDBAction', 'ListAction',
                              'NoRightsAction', 'LoginAction', 'myMVC_BaseLogoutAction'),
                        'MainAction', 'NoRightsAction');
// List of the valid views
$controller->setViews(array('MainView', 'TestView', 'Test1View', 'TestDBView', 'NoRightsView', 'LoginView', 'ListView'));
// Language information. Valid languages are german, english and italian.
// Default language is german. The path for the GetText-files is in ../locale and the domain is testmvc
$controller->setLanguageInformation(array('de_DE' => 'Deutsch', 'en_US' => 'English', 'it_IT' => 'Italiano'),
                                    'de_DE', $_SERVER['DOCUMENT_ROOT'].'/../locale', 'testmvc');
// Setting the PreAction-Filter using myMVC_LoginFilter (check if the user has logged in)
// As argument will be given the action to perform a login (LoginAction)
$controller->setFilter(myMVC_Controller::$FILTER_PREACTION, 'myMVC_LoginFilter', array(),
                       array('loginAction' => 'LoginAction'));
// Well, all parts of the program are configured. Now let start the controller...
$controller->process();

/**
 * Own exception handler.
 * It just display the exception...
 * 
 * @param Exception $exception    The exception
 */
function myCatcher($exception)
{
  print "ERROR:<br>\n";
  print_r($exception);
}
?>
